/* TextBar.c generated by valac 0.56.18, the Vala compiler
 * generated from TextBar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <pango/pango.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <granite.h>
#include <glib/gi18n-lib.h>

#define SPICE_WIDGETS_TEXT_TOOLBAR_TEXT_STYLE_CSS "\n        label {\n            font: 16px '%s';\n        }\n    "
#define SPICE_WIDGETS_TEXT_TOOLBAR_FONT_STYLE_CSS "\n" \
"        label {\n" \
"            font: %i %s 16px '%s';\n" \
"        }\n" \
"    "
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_WIDGETS_TYPE_TOOLBAR (spice_widgets_toolbar_get_type ())
#define SPICE_WIDGETS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbar))
#define SPICE_WIDGETS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))
#define SPICE_WIDGETS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))

typedef struct _SpiceWidgetsToolbar SpiceWidgetsToolbar;
typedef struct _SpiceWidgetsToolbarClass SpiceWidgetsToolbarClass;
typedef struct _SpiceWidgetsToolbarPrivate SpiceWidgetsToolbarPrivate;

#define SPICE_TYPE_CANVAS_ITEM (spice_canvas_item_get_type ())
#define SPICE_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItem))
#define SPICE_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))
#define SPICE_IS_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_IS_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_CANVAS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))

typedef struct _SpiceCanvasItem SpiceCanvasItem;
typedef struct _SpiceCanvasItemClass SpiceCanvasItemClass;

#define SPICE_WIDGETS_TYPE_TEXT_TOOLBAR (spice_widgets_text_toolbar_get_type ())
#define SPICE_WIDGETS_TEXT_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbar))
#define SPICE_WIDGETS_TEXT_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbarClass))
#define SPICE_WIDGETS_IS_TEXT_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR))
#define SPICE_WIDGETS_IS_TEXT_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR))
#define SPICE_WIDGETS_TEXT_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbarClass))

typedef struct _SpiceWidgetsTextToolbar SpiceWidgetsTextToolbar;
typedef struct _SpiceWidgetsTextToolbarClass SpiceWidgetsTextToolbarClass;
typedef struct _SpiceWidgetsTextToolbarPrivate SpiceWidgetsTextToolbarPrivate;

#define SPICE_TYPE_ENTRY_COMBO (spice_entry_combo_get_type ())
#define SPICE_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo))
#define SPICE_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))
#define SPICE_IS_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_IS_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_ENTRY_COMBO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))

typedef struct _SpiceEntryCombo SpiceEntryCombo;
typedef struct _SpiceEntryComboClass SpiceEntryComboClass;

#define SPICE_TYPE_COLOR_BUTTON (spice_color_button_get_type ())
#define SPICE_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButton))
#define SPICE_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))
#define SPICE_IS_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_IS_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_COLOR_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))

typedef struct _SpiceColorButton SpiceColorButton;
typedef struct _SpiceColorButtonClass SpiceColorButtonClass;

#define SPICE_TYPE_COLOR_CHOOSER (spice_color_chooser_get_type ())
#define SPICE_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooser))
#define SPICE_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))
#define SPICE_IS_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_IS_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_COLOR_CHOOSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))

typedef struct _SpiceColorChooser SpiceColorChooser;
typedef struct _SpiceColorChooserClass SpiceColorChooserClass;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_WIDGETS_TEXT_TOOLBAR_0_PROPERTY,
	SPICE_WIDGETS_TEXT_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* spice_widgets_text_toolbar_properties[SPICE_WIDGETS_TEXT_TOOLBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION (spice_services_history_manager_history_action_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryAction))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))

typedef struct _SpiceServicesHistoryManagerHistoryAction SpiceServicesHistoryManagerHistoryAction;
typedef struct _SpiceServicesHistoryManagerHistoryActionClass SpiceServicesHistoryManagerHistoryActionClass;

#define SPICE_TYPE_TEXT_ITEM (spice_text_item_get_type ())
#define SPICE_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_TEXT_ITEM, SpiceTextItem))
#define SPICE_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_TEXT_ITEM, SpiceTextItemClass))
#define SPICE_IS_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_TEXT_ITEM))
#define SPICE_IS_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_TEXT_ITEM))
#define SPICE_TEXT_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_TEXT_ITEM, SpiceTextItemClass))

typedef struct _SpiceTextItem SpiceTextItem;
typedef struct _SpiceTextItemClass SpiceTextItemClass;

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_SERVICES_TYPE_HISTORY_MANAGER (spice_services_history_manager_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManager))
#define SPICE_SERVICES_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))
#define SPICE_SERVICES_IS_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_IS_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_HISTORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))

typedef struct _SpiceServicesHistoryManager SpiceServicesHistoryManager;
typedef struct _SpiceServicesHistoryManagerClass SpiceServicesHistoryManagerClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_array_unref0(var) ((var == NULL) ? NULL : (var = (g_array_unref (var), NULL)))
#define __vala_PangoFontDescription_free0(var) ((var == NULL) ? NULL : (var = (_vala_PangoFontDescription_free (var), NULL)))
typedef struct _Block25Data Block25Data;

struct _SpiceWidgetsToolbar {
	GtkBox parent_instance;
	SpiceWidgetsToolbarPrivate * priv;
	gboolean init;
	gboolean selecting;
	SpiceCanvasItem* item;
};

struct _SpiceWidgetsToolbarClass {
	GtkBoxClass parent_class;
	void (*item_selected) (SpiceWidgetsToolbar* self, SpiceCanvasItem* item, gboolean new_item);
	void (*update_properties) (SpiceWidgetsToolbar* self);
};

struct _SpiceWidgetsTextToolbar {
	SpiceWidgetsToolbar parent_instance;
	SpiceWidgetsTextToolbarPrivate * priv;
};

struct _SpiceWidgetsTextToolbarClass {
	SpiceWidgetsToolbarClass parent_class;
};

struct _SpiceWidgetsTextToolbarPrivate {
	PangoFontFamily** families;
	gint families_length1;
	gint _families_size_;
	GeeHashMap* family_cache;
	GeeHashMap* face_cache;
	GraniteWidgetsModeButton* justification;
	GraniteWidgetsModeButton* align;
	SpiceEntryCombo* font_button;
	SpiceColorChooser* text_color_button;
	SpiceEntryCombo* font_size;
	SpiceEntryCombo* font_type;
	GtkImage* align_button_image;
	gchar** JUSTIFICATION_TRANSLATIONS;
	gint JUSTIFICATION_TRANSLATIONS_length1;
	gint _JUSTIFICATION_TRANSLATIONS_size_;
	gchar** ALIGN_TRANSLATIONS;
	gint ALIGN_TRANSLATIONS_length1;
	gint _ALIGN_TRANSLATIONS_size_;
	SpiceSlideManager* manager;
};

struct _Block25Data {
	int _ref_count_;
	SpiceWidgetsTextToolbar* self;
	GtkPopover* align_popover;
};

static gint SpiceWidgetsTextToolbar_private_offset;
static gpointer spice_widgets_text_toolbar_parent_class = NULL;

VALA_EXTERN GType spice_widgets_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsToolbar, g_object_unref)
VALA_EXTERN GType spice_canvas_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvasItem, g_object_unref)
VALA_EXTERN GType spice_widgets_text_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsTextToolbar, g_object_unref)
VALA_EXTERN GType spice_entry_combo_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceEntryCombo, g_object_unref)
VALA_EXTERN GType spice_color_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorButton, g_object_unref)
VALA_EXTERN GType spice_color_chooser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorChooser, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN void spice_widgets_toolbar_item_selected (SpiceWidgetsToolbar* self,
                                          SpiceCanvasItem* item,
                                          gboolean new_item);
VALA_EXTERN void spice_widgets_toolbar_update_properties (SpiceWidgetsToolbar* self);
VALA_EXTERN SpiceWidgetsTextToolbar* spice_widgets_text_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsTextToolbar* spice_widgets_text_toolbar_construct (GType object_type,
                                                               SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsToolbar* spice_widgets_toolbar_construct (GType object_type);
static void spice_widgets_text_toolbar_connect_signals (SpiceWidgetsTextToolbar* self);
static void __lambda102_ (SpiceWidgetsTextToolbar* self);
VALA_EXTERN GType spice_services_history_manager_history_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManagerHistoryAction, g_object_unref)
VALA_EXTERN GType spice_text_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceTextItem, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_new_item_changed (GType i_type,
                                                                                                          GBoxedCopyFunc i_dup_func,
                                                                                                          GDestroyNotify i_destroy_func,
                                                                                                          GType t_type,
                                                                                                          GBoxedCopyFunc t_dup_func,
                                                                                                          GDestroyNotify t_destroy_func,
                                                                                                          gconstpointer item,
                                                                                                          const gchar* property);
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_construct_item_changed (GType object_type,
                                                                                                                GType i_type,
                                                                                                                GBoxedCopyFunc i_dup_func,
                                                                                                                GDestroyNotify i_destroy_func,
                                                                                                                GType t_type,
                                                                                                                GBoxedCopyFunc t_dup_func,
                                                                                                                GDestroyNotify t_destroy_func,
                                                                                                                gconstpointer item,
                                                                                                                const gchar* property);
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN GType spice_services_history_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManager, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManager* spice_window_get_history_manager (SpiceWindow* self);
VALA_EXTERN void spice_services_history_manager_add_undoable_action (SpiceServicesHistoryManager* self,
                                                         SpiceServicesHistoryManagerHistoryAction* action,
                                                         gboolean force_add);
static void ___lambda102__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                     const gchar* color,
                                                     gpointer self);
static void __lambda103_ (SpiceWidgetsTextToolbar* self);
static void ___lambda103__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                const gchar* data,
                                                gpointer self);
static void __lambda104_ (SpiceWidgetsTextToolbar* self,
                   GtkWidget* widget);
static void ___lambda104__granite_widgets_mode_button_mode_changed (GraniteWidgetsModeButton* _sender,
                                                             GtkWidget* widget,
                                                             gpointer self);
static void __lambda105_ (SpiceWidgetsTextToolbar* self,
                   GtkWidget* widget);
static void ___lambda105__granite_widgets_mode_button_mode_changed (GraniteWidgetsModeButton* _sender,
                                                             GtkWidget* widget,
                                                             gpointer self);
static void __lambda106_ (SpiceWidgetsTextToolbar* self);
static void spice_widgets_text_toolbar_reset_font_type (SpiceWidgetsTextToolbar* self,
                                                 const gchar* selected_family);
VALA_EXTERN const gchar* spice_entry_combo_get_text (SpiceEntryCombo* self);
static void ___lambda106__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                const gchar* data,
                                                gpointer self);
static void __lambda107_ (SpiceWidgetsTextToolbar* self);
static void ___lambda107__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                const gchar* data,
                                                gpointer self);
static void spice_widgets_text_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                    SpiceCanvasItem* item,
                                                    gboolean new_item);
VALA_EXTERN const gchar* spice_text_item_get_font (SpiceTextItem* self);
VALA_EXTERN void spice_entry_combo_set_text (SpiceEntryCombo* self,
                                 const gchar* value);
VALA_EXTERN gint spice_text_item_get_font_size (SpiceTextItem* self);
VALA_EXTERN const gchar* spice_text_item_get_font_style (SpiceTextItem* self);
VALA_EXTERN const gchar* spice_text_item_get_font_color (SpiceTextItem* self);
VALA_EXTERN void spice_color_chooser_set_color (SpiceColorChooser* self,
                                    const gchar* value);
VALA_EXTERN gint spice_text_item_get_justification (SpiceTextItem* self);
VALA_EXTERN gint spice_text_item_get_align (SpiceTextItem* self);
static void spice_widgets_text_toolbar_real_update_properties (SpiceWidgetsToolbar* base);
VALA_EXTERN const gchar* spice_color_chooser_get_color (SpiceColorChooser* self);
VALA_EXTERN void spice_text_item_set_font_color (SpiceTextItem* self,
                                     const gchar* value);
VALA_EXTERN void spice_text_item_set_font (SpiceTextItem* self,
                               const gchar* value);
VALA_EXTERN void spice_text_item_set_font_style (SpiceTextItem* self,
                                     const gchar* value);
VALA_EXTERN void spice_text_item_set_font_size (SpiceTextItem* self,
                                    gint value);
VALA_EXTERN void spice_text_item_set_justification (SpiceTextItem* self,
                                        gint value);
VALA_EXTERN void spice_text_item_set_align (SpiceTextItem* self,
                                gint value);
VALA_EXTERN void spice_canvas_item_style (SpiceCanvasItem* self);
static PangoFontFace** _vala_array_dup4 (PangoFontFace** self,
                                  gssize length);
static void _g_object_unref0_ (gpointer var);
static void _vala_PangoFontFace_free_function_content_of (gpointer data);
VALA_EXTERN void spice_entry_combo_clear_all (SpiceEntryCombo* self);
VALA_EXTERN GtkLabel* spice_entry_combo_add_entry (SpiceEntryCombo* self,
                                       const gchar* real,
                                       const gchar* translated);
VALA_EXTERN void spice_utils_set_style (GtkWidget* widget,
                            const gchar* css);
static void _vala_PangoFontDescription_free (PangoFontDescription* self);
static GObject * spice_widgets_text_toolbar_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties);
static Block25Data* block25_data_ref (Block25Data* _data25_);
static void block25_data_unref (void * _userdata_);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_new (gboolean use_alpha);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_construct (GType object_type,
                                                  gboolean use_alpha);
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_new (gboolean strict_signal,
                                        gboolean alphabetize,
                                        gboolean searchable);
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_construct (GType object_type,
                                              gboolean strict_signal,
                                              gboolean alphabetize,
                                              gboolean searchable);
VALA_EXTERN void spice_entry_combo_set_max_length (SpiceEntryCombo* self,
                                       gint value);
VALA_EXTERN void spice_entry_combo_set_editable (SpiceEntryCombo* self,
                                     gboolean value);
static PangoFontFamily** _vala_array_dup5 (PangoFontFamily** self,
                                    gssize length);
static void _spice_widgets_text_toolbar___lambda108_ (Block25Data* _data25_);
static void __spice_widgets_text_toolbar___lambda108__gtk_button_clicked (GtkButton* _sender,
                                                                   gpointer self);
static void _spice_widgets_text_toolbar___lambda109_ (SpiceWidgetsTextToolbar* self,
                                               gint index,
                                               GtkWidget* widget);
static void __spice_widgets_text_toolbar___lambda109__granite_widgets_mode_button_mode_added (GraniteWidgetsModeButton* _sender,
                                                                                       gint index,
                                                                                       GtkWidget* widget,
                                                                                       gpointer self);
static void _spice_widgets_text_toolbar___lambda110_ (SpiceWidgetsTextToolbar* self,
                                               gint index,
                                               GtkWidget* widget);
static void __spice_widgets_text_toolbar___lambda110__granite_widgets_mode_button_mode_added (GraniteWidgetsModeButton* _sender,
                                                                                       gint index,
                                                                                       GtkWidget* widget,
                                                                                       gpointer self);
static void spice_widgets_text_toolbar_finalize (GObject * obj);
static GType spice_widgets_text_toolbar_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
spice_widgets_text_toolbar_get_instance_private (SpiceWidgetsTextToolbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceWidgetsTextToolbar_private_offset);
}

SpiceWidgetsTextToolbar*
spice_widgets_text_toolbar_construct (GType object_type,
                                      SpiceSlideManager* slide_manager)
{
	SpiceWidgetsTextToolbar * self = NULL;
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = (SpiceWidgetsTextToolbar*) spice_widgets_toolbar_construct (object_type);
#line 53 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->manager = slide_manager;
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return self;
#line 419 "TextBar.c"
}

SpiceWidgetsTextToolbar*
spice_widgets_text_toolbar_new (SpiceSlideManager* slide_manager)
{
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return spice_widgets_text_toolbar_construct (SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, slide_manager);
#line 427 "TextBar.c"
}

static void
__lambda102_ (SpiceWidgetsTextToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceServicesHistoryManagerHistoryAction* _tmp1_;
	SpiceSlideManager* _tmp2_;
	SpiceWindow* _tmp3_;
	SpiceWindow* _tmp4_;
	SpiceServicesHistoryManager* _tmp5_;
	SpiceServicesHistoryManager* _tmp6_;
#line 150 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 150 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SPICE_IS_TEXT_ITEM (_tmp0_) ? ((SpiceTextItem*) _tmp0_) : NULL, "font-color");
#line 150 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	action = _tmp1_;
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = self->priv->manager;
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = _tmp3_;
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = _tmp5_;
#line 151 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp6_, action, FALSE);
#line 152 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 149 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (action);
#line 463 "TextBar.c"
}

static void
___lambda102__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                const gchar* color,
                                                gpointer self)
{
#line 149 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda102_ ((SpiceWidgetsTextToolbar*) self);
#line 473 "TextBar.c"
}

static void
__lambda103_ (SpiceWidgetsTextToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceServicesHistoryManagerHistoryAction* _tmp1_;
	SpiceSlideManager* _tmp2_;
	SpiceWindow* _tmp3_;
	SpiceWindow* _tmp4_;
	SpiceServicesHistoryManager* _tmp5_;
	SpiceServicesHistoryManager* _tmp6_;
#line 156 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 156 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, SPICE_IS_TEXT_ITEM (_tmp0_) ? ((SpiceTextItem*) _tmp0_) : NULL, "font-size");
#line 156 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	action = _tmp1_;
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = self->priv->manager;
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = _tmp3_;
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = _tmp5_;
#line 157 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp6_, action, FALSE);
#line 158 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 155 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (action);
#line 509 "TextBar.c"
}

static void
___lambda103__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                           const gchar* data,
                                           gpointer self)
{
#line 155 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda103_ ((SpiceWidgetsTextToolbar*) self);
#line 519 "TextBar.c"
}

static void
__lambda104_ (SpiceWidgetsTextToolbar* self,
              GtkWidget* widget)
{
	GtkImage* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 161 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (widget != NULL);
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->align_button_image;
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (widget, gtk_image_get_type (), GtkImage), "icon-name", &_tmp1_, NULL);
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = _tmp1_;
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = _tmp2_;
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_set (_tmp0_, "icon-name", _tmp3_, NULL);
#line 162 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_free0 (_tmp3_);
#line 164 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (!((SpiceWidgetsToolbar*) self)->selecting) {
#line 546 "TextBar.c"
		SpiceServicesHistoryManagerHistoryAction* action = NULL;
		SpiceCanvasItem* _tmp4_;
		SpiceServicesHistoryManagerHistoryAction* _tmp5_;
		SpiceSlideManager* _tmp6_;
		SpiceWindow* _tmp7_;
		SpiceWindow* _tmp8_;
		SpiceServicesHistoryManager* _tmp9_;
		SpiceServicesHistoryManager* _tmp10_;
		SpiceServicesHistoryManagerHistoryAction* _tmp11_;
#line 165 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp4_ = ((SpiceWidgetsToolbar*) self)->item;
#line 165 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp5_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, SPICE_IS_TEXT_ITEM (_tmp4_) ? ((SpiceTextItem*) _tmp4_) : NULL, "justification");
#line 165 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		action = _tmp5_;
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp6_ = self->priv->manager;
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp7_ = spice_slide_manager_get_window (_tmp6_);
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp8_ = _tmp7_;
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp9_ = spice_window_get_history_manager (_tmp8_);
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp10_ = _tmp9_;
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp11_ = action;
#line 166 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_services_history_manager_add_undoable_action (_tmp10_, _tmp11_, FALSE);
#line 167 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 164 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_object_unref0 (action);
#line 580 "TextBar.c"
	}
}

static void
___lambda104__granite_widgets_mode_button_mode_changed (GraniteWidgetsModeButton* _sender,
                                                        GtkWidget* widget,
                                                        gpointer self)
{
#line 161 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda104_ ((SpiceWidgetsTextToolbar*) self, widget);
#line 591 "TextBar.c"
}

static void
__lambda105_ (SpiceWidgetsTextToolbar* self,
              GtkWidget* widget)
{
#line 171 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (widget != NULL);
#line 172 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (!((SpiceWidgetsToolbar*) self)->selecting) {
#line 602 "TextBar.c"
		SpiceServicesHistoryManagerHistoryAction* action = NULL;
		SpiceCanvasItem* _tmp0_;
		SpiceServicesHistoryManagerHistoryAction* _tmp1_;
		SpiceSlideManager* _tmp2_;
		SpiceWindow* _tmp3_;
		SpiceWindow* _tmp4_;
		SpiceServicesHistoryManager* _tmp5_;
		SpiceServicesHistoryManager* _tmp6_;
		SpiceServicesHistoryManagerHistoryAction* _tmp7_;
#line 173 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 173 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, SPICE_IS_TEXT_ITEM (_tmp0_) ? ((SpiceTextItem*) _tmp0_) : NULL, "align");
#line 173 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		action = _tmp1_;
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp2_ = self->priv->manager;
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp4_ = _tmp3_;
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp6_ = _tmp5_;
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp7_ = action;
#line 174 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_services_history_manager_add_undoable_action (_tmp6_, _tmp7_, FALSE);
#line 175 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 172 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_object_unref0 (action);
#line 636 "TextBar.c"
	}
}

static void
___lambda105__granite_widgets_mode_button_mode_changed (GraniteWidgetsModeButton* _sender,
                                                        GtkWidget* widget,
                                                        gpointer self)
{
#line 171 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda105_ ((SpiceWidgetsTextToolbar*) self, widget);
#line 647 "TextBar.c"
}

static void
__lambda106_ (SpiceWidgetsTextToolbar* self)
{
	SpiceEntryCombo* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp3_;
	SpiceServicesHistoryManagerHistoryAction* _tmp4_;
	SpiceSlideManager* _tmp5_;
	SpiceWindow* _tmp6_;
	SpiceWindow* _tmp7_;
	SpiceServicesHistoryManager* _tmp8_;
	SpiceServicesHistoryManager* _tmp9_;
#line 180 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->font_button;
#line 180 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = spice_entry_combo_get_text (_tmp0_);
#line 180 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = _tmp1_;
#line 180 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_text_toolbar_reset_font_type (self, _tmp2_);
#line 182 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = ((SpiceWidgetsToolbar*) self)->item;
#line 182 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SPICE_IS_TEXT_ITEM (_tmp3_) ? ((SpiceTextItem*) _tmp3_) : NULL, "font");
#line 182 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	action = _tmp4_;
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = self->priv->manager;
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = spice_slide_manager_get_window (_tmp5_);
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp7_ = _tmp6_;
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_ = spice_window_get_history_manager (_tmp7_);
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp9_ = _tmp8_;
#line 183 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp9_, action, FALSE);
#line 185 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 179 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (action);
#line 694 "TextBar.c"
}

static void
___lambda106__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                           const gchar* data,
                                           gpointer self)
{
#line 179 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda106_ ((SpiceWidgetsTextToolbar*) self);
#line 704 "TextBar.c"
}

static void
__lambda107_ (SpiceWidgetsTextToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceServicesHistoryManagerHistoryAction* _tmp1_;
	SpiceSlideManager* _tmp2_;
	SpiceWindow* _tmp3_;
	SpiceWindow* _tmp4_;
	SpiceServicesHistoryManager* _tmp5_;
	SpiceServicesHistoryManager* _tmp6_;
#line 189 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 189 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_TEXT_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SPICE_IS_TEXT_ITEM (_tmp0_) ? ((SpiceTextItem*) _tmp0_) : NULL, "font-style");
#line 189 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	action = _tmp1_;
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = self->priv->manager;
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = _tmp3_;
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = _tmp5_;
#line 190 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp6_, action, FALSE);
#line 191 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 188 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (action);
#line 740 "TextBar.c"
}

static void
___lambda107__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                           const gchar* data,
                                           gpointer self)
{
#line 188 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	__lambda107_ ((SpiceWidgetsTextToolbar*) self);
#line 750 "TextBar.c"
}

static void
spice_widgets_text_toolbar_connect_signals (SpiceWidgetsTextToolbar* self)
{
	SpiceColorChooser* _tmp0_;
	SpiceEntryCombo* _tmp1_;
	GraniteWidgetsModeButton* _tmp2_;
	GraniteWidgetsModeButton* _tmp3_;
	SpiceEntryCombo* _tmp4_;
	SpiceEntryCombo* _tmp5_;
#line 148 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (self != NULL);
#line 149 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->text_color_button;
#line 149 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp0_, "color-picked", (GCallback) ___lambda102__spice_color_chooser_color_picked, self, 0);
#line 155 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = self->priv->font_size;
#line 155 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp1_, "activated", (GCallback) ___lambda103__spice_entry_combo_activated, self, 0);
#line 161 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = self->priv->justification;
#line 161 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp2_, "mode-changed", (GCallback) ___lambda104__granite_widgets_mode_button_mode_changed, self, 0);
#line 171 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = self->priv->align;
#line 171 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp3_, "mode-changed", (GCallback) ___lambda105__granite_widgets_mode_button_mode_changed, self, 0);
#line 179 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = self->priv->font_button;
#line 179 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp4_, "activated", (GCallback) ___lambda106__spice_entry_combo_activated, self, 0);
#line 188 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = self->priv->font_type;
#line 188 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp5_, "activated", (GCallback) ___lambda107__spice_entry_combo_activated, self, 0);
#line 788 "TextBar.c"
}

static void
spice_widgets_text_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                               SpiceCanvasItem* item,
                                               gboolean new_item)
{
	SpiceWidgetsTextToolbar * self;
	SpiceEntryCombo* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	SpiceEntryCombo* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	SpiceEntryCombo* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	SpiceColorChooser* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	GraniteWidgetsModeButton* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GraniteWidgetsModeButton* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
#line 196 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = (SpiceWidgetsTextToolbar*) base;
#line 197 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (new_item) {
#line 198 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 199 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		return;
#line 827 "TextBar.c"
	}
#line 202 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->font_button;
#line 202 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = spice_text_item_get_font (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 202 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = _tmp1_;
#line 202 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_text (_tmp0_, _tmp2_);
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = self->priv->font_size;
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = spice_text_item_get_font_size (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = _tmp4_;
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = g_strdup_printf ("%i", _tmp5_);
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp7_ = _tmp6_;
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_text (_tmp3_, _tmp7_);
#line 203 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_free0 (_tmp7_);
#line 205 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_ = spice_text_item_get_font (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 205 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp9_ = _tmp8_;
#line 205 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_text_toolbar_reset_font_type (self, _tmp9_);
#line 206 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp10_ = self->priv->font_type;
#line 206 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp11_ = spice_text_item_get_font_style (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 206 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp12_ = _tmp11_;
#line 206 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_text (_tmp10_, _tmp12_);
#line 208 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp13_ = self->priv->text_color_button;
#line 208 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp14_ = spice_text_item_get_font_color (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 208 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp15_ = _tmp14_;
#line 208 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_color_chooser_set_color (_tmp13_, _tmp15_);
#line 209 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp16_ = self->priv->justification;
#line 209 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp17_ = spice_text_item_get_justification (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 209 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp18_ = _tmp17_;
#line 209 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_set_active (_tmp16_, _tmp18_);
#line 210 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp19_ = self->priv->align;
#line 210 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp20_ = spice_text_item_get_align (G_TYPE_CHECK_INSTANCE_CAST (item, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 210 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp21_ = _tmp20_;
#line 210 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_set_active (_tmp19_, _tmp21_);
#line 889 "TextBar.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 214 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return self ? g_object_ref (self) : NULL;
#line 897 "TextBar.c"
}

static void
spice_widgets_text_toolbar_real_update_properties (SpiceWidgetsToolbar* base)
{
	SpiceWidgetsTextToolbar * self;
	SpiceTextItem* text = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceTextItem* _tmp1_;
	SpiceColorChooser* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	SpiceEntryCombo* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	SpiceEntryCombo* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	SpiceEntryCombo* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	GraniteWidgetsModeButton* _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	GraniteWidgetsModeButton* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	SpiceCanvasItem* _tmp20_;
#line 213 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = (SpiceWidgetsTextToolbar*) base;
#line 214 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 214 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPICE_TYPE_TEXT_ITEM, SpiceTextItem));
#line 214 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	text = _tmp1_;
#line 215 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = self->priv->text_color_button;
#line 215 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = spice_color_chooser_get_color (_tmp2_);
#line 215 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = _tmp3_;
#line 215 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_font_color (text, _tmp4_);
#line 216 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = self->priv->font_button;
#line 216 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = spice_entry_combo_get_text (_tmp5_);
#line 216 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp7_ = _tmp6_;
#line 216 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_font (text, _tmp7_);
#line 217 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_ = self->priv->font_type;
#line 217 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp9_ = spice_entry_combo_get_text (_tmp8_);
#line 217 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp10_ = _tmp9_;
#line 217 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_font_style (text, _tmp10_);
#line 218 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp11_ = self->priv->font_size;
#line 218 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp12_ = spice_entry_combo_get_text (_tmp11_);
#line 218 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp13_ = _tmp12_;
#line 218 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_font_size (text, atoi (_tmp13_));
#line 219 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp14_ = self->priv->justification;
#line 219 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp15_ = granite_widgets_mode_button_get_selected (_tmp14_);
#line 219 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp16_ = _tmp15_;
#line 219 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_justification (text, _tmp16_);
#line 220 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp17_ = self->priv->align;
#line 220 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp18_ = granite_widgets_mode_button_get_selected (_tmp17_);
#line 220 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp19_ = _tmp18_;
#line 220 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_text_item_set_align (text, _tmp19_);
#line 222 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp20_ = ((SpiceWidgetsToolbar*) self)->item;
#line 222 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_canvas_item_style (_tmp20_);
#line 213 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (text);
#line 988 "TextBar.c"
}

static PangoFontFace**
_vala_array_dup4 (PangoFontFace** self,
                  gssize length)
{
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (length >= 0) {
#line 997 "TextBar.c"
		PangoFontFace** result;
		gssize i;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		result = g_new0 (PangoFontFace*, length + 1);
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (i = 0; i < length; i++) {
#line 1004 "TextBar.c"
			PangoFontFace* _tmp0_;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp0_ = _g_object_ref0 (self[i]);
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			result[i] = _tmp0_;
#line 1010 "TextBar.c"
		}
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		return result;
#line 1014 "TextBar.c"
	}
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return NULL;
#line 1018 "TextBar.c"
}

static void
_g_object_unref0_ (gpointer var)
{
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1026 "TextBar.c"
}

static void
_vala_PangoFontFace_free_function_content_of (gpointer data)
{
	PangoFontFace* self;
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = *((PangoFontFace**) data);
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0_ (self);
#line 1037 "TextBar.c"
}

static void
_vala_PangoFontDescription_free (PangoFontDescription* self)
{
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_boxed_free (pango_font_description_get_type (), self);
#line 1045 "TextBar.c"
}

static void
spice_widgets_text_toolbar_reset_font_type (SpiceWidgetsTextToolbar* self,
                                            const gchar* selected_family)
{
	gchar* key = NULL;
	gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 225 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (self != NULL);
#line 225 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (selected_family != NULL);
#line 226 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = g_utf8_strdown (selected_family, (gssize) -1);
#line 226 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	key = _tmp0_;
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (selected_family != NULL) {
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp2_ = g_strcmp0 (selected_family, "") != 0;
#line 1068 "TextBar.c"
	} else {
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp2_ = FALSE;
#line 1072 "TextBar.c"
	}
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (_tmp2_) {
#line 1076 "TextBar.c"
		GeeHashMap* _tmp3_;
		const gchar* _tmp4_;
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp3_ = self->priv->family_cache;
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp4_ = key;
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp1_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp3_, _tmp4_);
#line 1085 "TextBar.c"
	} else {
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp1_ = FALSE;
#line 1089 "TextBar.c"
	}
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (_tmp1_) {
#line 1093 "TextBar.c"
		const gchar* _tmp5_;
		SpiceEntryCombo* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		GArray* font_faces = NULL;
		GeeHashMap* _tmp9_;
		const gchar* _tmp10_;
		SpiceEntryCombo* _tmp30_;
		gchar* family_name = NULL;
		GeeHashMap* _tmp31_;
		const gchar* _tmp32_;
		gpointer _tmp33_;
		PangoFontFamily* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp5_ = key;
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp6_ = self->priv->font_type;
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp7_ = spice_entry_combo_get_text (_tmp6_);
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp8_ = _tmp7_;
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		if (g_strcmp0 (_tmp5_, _tmp8_) == 0) {
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_g_free0 (key);
#line 229 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			return;
#line 1124 "TextBar.c"
		}
#line 233 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp9_ = self->priv->face_cache;
#line 233 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp10_ = key;
#line 233 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp9_, _tmp10_)) {
#line 1132 "TextBar.c"
			GeeHashMap* _tmp11_;
			const gchar* _tmp12_;
			gpointer _tmp13_;
#line 234 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp11_ = self->priv->face_cache;
#line 234 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp12_ = key;
#line 234 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp13_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp11_, _tmp12_);
#line 234 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_g_array_unref0 (font_faces);
#line 234 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			font_faces = (GArray*) _tmp13_;
#line 1146 "TextBar.c"
		} else {
			PangoFontFace** temp_face = NULL;
			gint temp_face_length1 = 0;
			gint _temp_face_size_ = 0;
			PangoFontFamily* family = NULL;
			GeeHashMap* _tmp14_;
			const gchar* _tmp15_;
			gpointer _tmp16_;
			PangoFontFamily* _tmp17_;
			PangoFontFace** _tmp18_ = NULL;
			gint _tmp19_ = 0;
			PangoFontFace** _tmp20_;
			gint _tmp20__length1;
			GArray* _tmp21_;
			PangoFontFace** _tmp22_;
			gint _tmp22__length1;
			GeeHashMap* _tmp27_;
			const gchar* _tmp28_;
			GArray* _tmp29_;
#line 237 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp14_ = self->priv->family_cache;
#line 237 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp15_ = key;
#line 237 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, _tmp15_);
#line 237 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			family = (PangoFontFamily*) _tmp16_;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp17_ = family;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			pango_font_family_list_faces (_tmp17_, &_tmp18_, &_tmp19_);
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			temp_face = (_vala_array_free (temp_face, temp_face_length1, (GDestroyNotify) g_object_unref), NULL);
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp20_ = (_tmp18_ != NULL) ? _vala_array_dup4 (_tmp18_, _tmp19_) : _tmp18_;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp20__length1 = _tmp19_;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp18_ = (g_free (_tmp18_), NULL);
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			temp_face = _tmp20_;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			temp_face_length1 = _tmp20__length1;
#line 238 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_temp_face_size_ = temp_face_length1;
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp21_ = g_array_new (TRUE, TRUE, sizeof (PangoFontFace*));
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			g_array_set_clear_func (_tmp21_, (GDestroyNotify) _vala_PangoFontFace_free_function_content_of);
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_g_array_unref0 (font_faces);
#line 239 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			font_faces = _tmp21_;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp22_ = temp_face;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp22__length1 = temp_face_length1;
#line 1204 "TextBar.c"
			{
				PangoFontFace** face_collection = NULL;
				gint face_collection_length1 = 0;
				gint _face_collection_size_ = 0;
				gint face_it = 0;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				face_collection = _tmp22_;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				face_collection_length1 = _tmp22__length1;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				for (face_it = 0; face_it < face_collection_length1; face_it = face_it + 1) {
#line 1216 "TextBar.c"
					PangoFontFace* _tmp23_;
					PangoFontFace* face = NULL;
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp23_ = _g_object_ref0 (face_collection[face_it]);
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					face = _tmp23_;
#line 1223 "TextBar.c"
					{
						GArray* _tmp24_;
						PangoFontFace* _tmp25_;
						PangoFontFace* _tmp26_;
#line 241 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						_tmp24_ = font_faces;
#line 241 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						_tmp25_ = face;
#line 241 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						_tmp26_ = _g_object_ref0 (_tmp25_);
#line 241 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						g_array_append_val (_tmp24_, _tmp26_);
#line 240 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						_g_object_unref0 (face);
#line 1238 "TextBar.c"
					}
				}
			}
#line 244 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp27_ = self->priv->face_cache;
#line 244 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp28_ = key;
#line 244 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp29_ = font_faces;
#line 244 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp27_, _tmp28_, _tmp29_);
#line 233 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_g_object_unref0 (family);
#line 233 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			temp_face = (_vala_array_free (temp_face, temp_face_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1254 "TextBar.c"
		}
#line 247 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp30_ = self->priv->font_type;
#line 247 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		spice_entry_combo_clear_all (_tmp30_);
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp31_ = self->priv->family_cache;
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp32_ = key;
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp33_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp31_, _tmp32_);
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp34_ = (PangoFontFamily*) _tmp33_;
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp35_ = pango_font_family_get_name (_tmp34_);
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp36_ = g_strdup (_tmp35_);
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_tmp37_ = _tmp36_;
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_object_unref0 (_tmp34_);
#line 249 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		family_name = _tmp37_;
#line 1278 "TextBar.c"
		{
			gint i = 0;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			i = 0;
#line 1283 "TextBar.c"
			{
				gboolean _tmp38_ = FALSE;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp38_ = TRUE;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				while (TRUE) {
#line 1290 "TextBar.c"
					GArray* _tmp40_;
					PangoFontFace* font_face = NULL;
					GArray* _tmp41_;
					PangoFontFace* _tmp42_;
					PangoFontFace* _tmp43_;
					GtkLabel* entry = NULL;
					SpiceEntryCombo* _tmp44_;
					PangoFontFace* _tmp45_;
					const gchar* _tmp46_;
					GtkLabel* _tmp47_;
					PangoFontDescription* description = NULL;
					PangoFontFace* _tmp48_;
					PangoFontDescription* _tmp49_;
					gchar* style = NULL;
					gchar* _tmp50_;
					PangoFontDescription* _tmp51_;
					gint weight = 0;
					PangoFontDescription* _tmp54_;
					GtkLabel* _tmp55_;
					const gchar* _tmp56_;
					const gchar* _tmp57_;
					gchar* _tmp58_;
					gchar* _tmp59_;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					if (!_tmp38_) {
#line 1316 "TextBar.c"
						gint _tmp39_;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						_tmp39_ = i;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						i = _tmp39_ + 1;
#line 1322 "TextBar.c"
					}
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp38_ = FALSE;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp40_ = font_faces;
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					if (!(((guint) i) < _tmp40_->len)) {
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						break;
#line 1332 "TextBar.c"
					}
#line 252 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp41_ = font_faces;
#line 252 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp42_ = g_array_index (_tmp41_, PangoFontFace*, (guint) i);
#line 252 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp43_ = _g_object_ref0 (_tmp42_);
#line 252 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					font_face = _tmp43_;
#line 253 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp44_ = self->priv->font_type;
#line 253 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp45_ = font_face;
#line 253 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp46_ = pango_font_face_get_face_name (_tmp45_);
#line 253 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp47_ = spice_entry_combo_add_entry (_tmp44_, _tmp46_, NULL);
#line 253 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					entry = _tmp47_;
#line 255 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp48_ = font_face;
#line 255 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp49_ = pango_font_face_describe (_tmp48_);
#line 255 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					description = _tmp49_;
#line 256 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp50_ = g_strdup ("normal");
#line 256 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					style = _tmp50_;
#line 257 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp51_ = description;
#line 257 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					switch (pango_font_description_get_style (_tmp51_)) {
#line 257 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_STYLE_OBLIQUE:
#line 1368 "TextBar.c"
						{
							gchar* _tmp52_;
#line 258 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							_tmp52_ = g_strdup ("oblique");
#line 258 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							_g_free0 (style);
#line 258 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							style = _tmp52_;
#line 258 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1379 "TextBar.c"
						}
#line 257 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_STYLE_ITALIC:
#line 1383 "TextBar.c"
						{
							gchar* _tmp53_;
#line 259 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							_tmp53_ = g_strdup ("italic");
#line 259 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							_g_free0 (style);
#line 259 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							style = _tmp53_;
#line 259 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1394 "TextBar.c"
						}
						default:
#line 257 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						break;
#line 1399 "TextBar.c"
					}
#line 262 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					weight = 400;
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp54_ = description;
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					switch (pango_font_description_get_weight (_tmp54_)) {
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_THIN:
#line 1409 "TextBar.c"
						{
#line 264 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 100;
#line 264 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1415 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_ULTRALIGHT:
#line 1419 "TextBar.c"
						{
#line 265 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 200;
#line 265 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1425 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_LIGHT:
#line 1429 "TextBar.c"
						{
#line 266 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 300;
#line 266 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1435 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_SEMILIGHT:
#line 1439 "TextBar.c"
						{
#line 267 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 350;
#line 267 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1445 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_BOOK:
#line 1449 "TextBar.c"
						{
#line 268 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 380;
#line 268 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1455 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_NORMAL:
#line 1459 "TextBar.c"
						{
#line 269 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 400;
#line 269 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1465 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_MEDIUM:
#line 1469 "TextBar.c"
						{
#line 270 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 500;
#line 270 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1475 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_SEMIBOLD:
#line 1479 "TextBar.c"
						{
#line 271 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 600;
#line 271 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1485 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_BOLD:
#line 1489 "TextBar.c"
						{
#line 272 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 700;
#line 272 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1495 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_ULTRABOLD:
#line 1499 "TextBar.c"
						{
#line 273 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 800;
#line 273 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1505 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_HEAVY:
#line 1509 "TextBar.c"
						{
#line 274 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 900;
#line 274 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1515 "TextBar.c"
						}
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						case PANGO_WEIGHT_ULTRAHEAVY:
#line 1519 "TextBar.c"
						{
#line 275 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							weight = 1000;
#line 275 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
							break;
#line 1525 "TextBar.c"
						}
						default:
#line 263 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
						break;
#line 1530 "TextBar.c"
					}
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp55_ = entry;
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp56_ = style;
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp57_ = family_name;
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp58_ = g_strdup_printf (SPICE_WIDGETS_TEXT_TOOLBAR_FONT_STYLE_CSS, weight, _tmp56_, _tmp57_);
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_tmp59_ = _tmp58_;
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					spice_utils_set_style ((GtkWidget*) _tmp55_, _tmp59_);
#line 278 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_g_free0 (_tmp59_);
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_g_free0 (style);
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					__vala_PangoFontDescription_free0 (description);
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_g_object_unref0 (entry);
#line 251 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
					_g_object_unref0 (font_face);
#line 1554 "TextBar.c"
				}
			}
		}
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_free0 (family_name);
#line 228 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_array_unref0 (font_faces);
#line 1562 "TextBar.c"
	}
#line 225 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_free0 (key);
#line 1566 "TextBar.c"
}

static Block25Data*
block25_data_ref (Block25Data* _data25_)
{
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_atomic_int_inc (&_data25_->_ref_count_);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return _data25_;
#line 1576 "TextBar.c"
}

static void
block25_data_unref (void * _userdata_)
{
	Block25Data* _data25_;
	_data25_ = (Block25Data*) _userdata_;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (g_atomic_int_dec_and_test (&_data25_->_ref_count_)) {
#line 1586 "TextBar.c"
		SpiceWidgetsTextToolbar* self;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		self = _data25_->self;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_object_unref0 (_data25_->align_popover);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		_g_object_unref0 (self);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		g_slice_free (Block25Data, _data25_);
#line 1596 "TextBar.c"
	}
}

static PangoFontFamily**
_vala_array_dup5 (PangoFontFamily** self,
                  gssize length)
{
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	if (length >= 0) {
#line 1606 "TextBar.c"
		PangoFontFamily** result;
		gssize i;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		result = g_new0 (PangoFontFamily*, length + 1);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (i = 0; i < length; i++) {
#line 1613 "TextBar.c"
			PangoFontFamily* _tmp0_;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp0_ = _g_object_ref0 (self[i]);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			result[i] = _tmp0_;
#line 1619 "TextBar.c"
		}
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		return result;
#line 1623 "TextBar.c"
	}
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return NULL;
#line 1627 "TextBar.c"
}

static void
_spice_widgets_text_toolbar___lambda108_ (Block25Data* _data25_)
{
	SpiceWidgetsTextToolbar* self;
	GtkPopover* _tmp0_;
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = _data25_->self;
#line 104 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = _data25_->align_popover;
#line 104 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp0_);
#line 1641 "TextBar.c"
}

static void
__spice_widgets_text_toolbar___lambda108__gtk_button_clicked (GtkButton* _sender,
                                                              gpointer self)
{
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_spice_widgets_text_toolbar___lambda108_ (self);
#line 1650 "TextBar.c"
}

static void
_spice_widgets_text_toolbar___lambda109_ (SpiceWidgetsTextToolbar* self,
                                          gint index,
                                          GtkWidget* widget)
{
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
#line 108 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (widget != NULL);
#line 109 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->JUSTIFICATION_TRANSLATIONS;
#line 109 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0__length1 = self->priv->JUSTIFICATION_TRANSLATIONS_length1;
#line 109 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = _tmp0_[index];
#line 109 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text (widget, _tmp1_);
#line 110 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_set (widget, "margin", 3, NULL);
#line 1673 "TextBar.c"
}

static void
__spice_widgets_text_toolbar___lambda109__granite_widgets_mode_button_mode_added (GraniteWidgetsModeButton* _sender,
                                                                                  gint index,
                                                                                  GtkWidget* widget,
                                                                                  gpointer self)
{
#line 108 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_spice_widgets_text_toolbar___lambda109_ ((SpiceWidgetsTextToolbar*) self, index, widget);
#line 1684 "TextBar.c"
}

static void
_spice_widgets_text_toolbar___lambda110_ (SpiceWidgetsTextToolbar* self,
                                          gint index,
                                          GtkWidget* widget)
{
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
#line 123 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_return_if_fail (widget != NULL);
#line 124 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = self->priv->ALIGN_TRANSLATIONS;
#line 124 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0__length1 = self->priv->ALIGN_TRANSLATIONS_length1;
#line 124 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = _tmp0_[index];
#line 124 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text (widget, _tmp1_);
#line 125 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_set (widget, "margin", 3, NULL);
#line 1707 "TextBar.c"
}

static void
__spice_widgets_text_toolbar___lambda110__granite_widgets_mode_button_mode_added (GraniteWidgetsModeButton* _sender,
                                                                                  gint index,
                                                                                  GtkWidget* widget,
                                                                                  gpointer self)
{
#line 123 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_spice_widgets_text_toolbar___lambda110_ ((SpiceWidgetsTextToolbar*) self, index, widget);
#line 1718 "TextBar.c"
}

static GObject *
spice_widgets_text_toolbar_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceWidgetsTextToolbar * self;
	Block25Data* _data25_;
	SpiceColorChooser* _tmp0_;
	SpiceColorChooser* _tmp1_;
	SpiceEntryCombo* _tmp2_;
	SpiceEntryCombo* _tmp3_;
	SpiceEntryCombo* _tmp4_;
	SpiceEntryCombo* _tmp5_;
	GeeHashMap* _tmp6_;
	GeeHashMap* _tmp7_;
	SpiceEntryCombo* _tmp8_;
	SpiceEntryCombo* _tmp9_;
	SpiceEntryCombo* _tmp10_;
	PangoContext* _tmp11_;
	PangoContext* _tmp12_;
	PangoFontFamily** _tmp13_ = NULL;
	gint _tmp14_ = 0;
	PangoFontFamily** _tmp15_;
	gint _tmp15__length1;
	PangoFontFamily** _tmp16_;
	gint _tmp16__length1;
	gint* font_sizes = NULL;
	gint* _tmp33_;
	gint font_sizes_length1;
	gint _font_sizes_size_;
	SpiceEntryCombo* _tmp34_;
	SpiceEntryCombo* _tmp35_;
	SpiceEntryCombo* _tmp36_;
	gint* _tmp37_;
	gint _tmp37__length1;
	GtkImage* _tmp43_;
	GtkButton* align_button = NULL;
	GtkButton* _tmp44_;
	GtkButton* _tmp45_;
	GtkStyleContext* _tmp46_;
	GtkButton* _tmp47_;
	GtkButton* _tmp48_;
	GtkImage* _tmp49_;
	GtkGrid* align_grid = NULL;
	GtkGrid* _tmp50_;
	GtkGrid* _tmp51_;
	GtkGrid* _tmp52_;
	GtkGrid* _tmp53_;
	GtkButton* _tmp54_;
	GtkPopover* _tmp55_;
	GtkPopover* _tmp56_;
	GtkPopover* _tmp57_;
	GtkGrid* _tmp58_;
	GtkButton* _tmp59_;
	GraniteWidgetsModeButton* _tmp60_;
	GraniteWidgetsModeButton* _tmp61_;
	GraniteWidgetsModeButton* _tmp62_;
	GraniteWidgetsModeButton* _tmp63_;
	GraniteWidgetsModeButton* _tmp64_;
	GraniteWidgetsModeButton* _tmp65_;
	GraniteWidgetsModeButton* _tmp66_;
	GList* _tmp67_;
	GraniteWidgetsModeButton* _tmp70_;
	GraniteWidgetsModeButton* _tmp71_;
	GraniteWidgetsModeButton* _tmp72_;
	GtkImage* _tmp73_;
	GtkImage* _tmp74_;
	GraniteWidgetsModeButton* _tmp75_;
	GtkImage* _tmp76_;
	GtkImage* _tmp77_;
	GraniteWidgetsModeButton* _tmp78_;
	GtkImage* _tmp79_;
	GtkImage* _tmp80_;
	GraniteWidgetsModeButton* _tmp81_;
	GList* _tmp82_;
	SpiceColorChooser* _tmp85_;
	SpiceEntryCombo* _tmp86_;
	SpiceEntryCombo* _tmp87_;
	SpiceEntryCombo* _tmp88_;
	GtkButton* _tmp89_;
	GtkGrid* _tmp90_;
	GraniteWidgetsModeButton* _tmp91_;
	GtkGrid* _tmp92_;
	GraniteWidgetsModeButton* _tmp93_;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	parent_class = G_OBJECT_CLASS (spice_widgets_text_toolbar_parent_class);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbar);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_data25_ = g_slice_new0 (Block25Data);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_data25_->_ref_count_ = 1;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_data25_->self = g_object_ref (self);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = spice_color_chooser_new (TRUE);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp0_);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->text_color_button);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->text_color_button = _tmp0_;
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = self->priv->text_color_button;
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp1_, _ ("Font color"));
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = spice_entry_combo_new (TRUE, TRUE, FALSE);
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp2_);
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_type);
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->font_type = _tmp2_;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = self->priv->font_type;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp3_, _ ("Font Style"));
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = self->priv->font_type;
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_max_length (_tmp4_, 10);
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = self->priv->font_type;
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_editable (_tmp5_, FALSE);
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, pango_font_family_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->family_cache);
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->family_cache = _tmp6_;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp7_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_ARRAY, (GBoxedCopyFunc) g_array_ref, (GDestroyNotify) g_array_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->face_cache);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->face_cache = _tmp7_;
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_ = spice_entry_combo_new (TRUE, TRUE, TRUE);
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp8_);
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_button);
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->font_button = _tmp8_;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp9_ = self->priv->font_button;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp9_, _ ("Font"));
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp10_ = self->priv->font_button;
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_editable (_tmp10_, FALSE);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp11_ = gtk_widget_create_pango_context ((GtkWidget*) self);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp12_ = _tmp11_;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	pango_context_list_families (_tmp12_, &_tmp13_, &_tmp14_);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->families = (_vala_array_free (self->priv->families, self->priv->families_length1, (GDestroyNotify) g_object_unref), NULL);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp15_ = (_tmp13_ != NULL) ? _vala_array_dup5 (_tmp13_, _tmp14_) : _tmp13_;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp15__length1 = _tmp14_;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp13_ = (g_free (_tmp13_), NULL);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->families = _tmp15_;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->families_length1 = _tmp15__length1;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->_families_size_ = self->priv->families_length1;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (_tmp12_);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp16_ = self->priv->families;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp16__length1 = self->priv->families_length1;
#line 1905 "TextBar.c"
	{
		PangoFontFamily** family_collection = NULL;
		gint family_collection_length1 = 0;
		gint _family_collection_size_ = 0;
		gint family_it = 0;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		family_collection = _tmp16_;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		family_collection_length1 = _tmp16__length1;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (family_it = 0; family_it < family_collection_length1; family_it = family_it + 1) {
#line 1917 "TextBar.c"
			PangoFontFamily* _tmp17_;
			PangoFontFamily* family = NULL;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			_tmp17_ = _g_object_ref0 (family_collection[family_it]);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			family = _tmp17_;
#line 1924 "TextBar.c"
			{
				GtkLabel* entry = NULL;
				SpiceEntryCombo* _tmp18_;
				PangoFontFamily* _tmp19_;
				const gchar* _tmp20_;
				GtkLabel* _tmp21_;
				GtkLabel* _tmp22_;
				PangoFontFamily* _tmp23_;
				const gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				GeeHashMap* _tmp27_;
				PangoFontFamily* _tmp28_;
				const gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				PangoFontFamily* _tmp32_;
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp18_ = self->priv->font_button;
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp19_ = family;
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp20_ = pango_font_family_get_name (_tmp19_);
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp21_ = spice_entry_combo_add_entry (_tmp18_, _tmp20_, NULL);
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				entry = _tmp21_;
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp22_ = entry;
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp23_ = family;
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp24_ = pango_font_family_get_name (_tmp23_);
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp25_ = g_strdup_printf (SPICE_WIDGETS_TEXT_TOOLBAR_TEXT_STYLE_CSS, _tmp24_);
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp26_ = _tmp25_;
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				spice_utils_set_style ((GtkWidget*) _tmp22_, _tmp26_);
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_free0 (_tmp26_);
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp27_ = self->priv->family_cache;
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp28_ = family;
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp29_ = pango_font_family_get_name (_tmp28_);
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp30_ = g_utf8_strdown (_tmp29_, (gssize) -1);
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp31_ = _tmp30_;
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp32_ = family;
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				gee_abstract_map_set ((GeeAbstractMap*) _tmp27_, _tmp31_, _tmp32_);
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_free0 (_tmp31_);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_object_unref0 (entry);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_object_unref0 (family);
#line 1986 "TextBar.c"
			}
		}
	}
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_ = g_new0 (gint, 11);
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[0] = 5;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[1] = 7;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[2] = 9;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[3] = 12;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[4] = 16;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[5] = 21;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[6] = 28;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[7] = 37;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[8] = 42;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[9] = 50;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp33_[10] = 67;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	font_sizes = _tmp33_;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	font_sizes_length1 = 11;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_font_sizes_size_ = font_sizes_length1;
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp34_ = spice_entry_combo_new (FALSE, FALSE, FALSE);
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp34_);
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_size);
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->font_size = _tmp34_;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp35_ = self->priv->font_size;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp35_, _ ("Font size"));
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp36_ = self->priv->font_size;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_entry_combo_set_max_length (_tmp36_, 3);
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp37_ = font_sizes;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp37__length1 = font_sizes_length1;
#line 2040 "TextBar.c"
	{
		gint* size_collection = NULL;
		gint size_collection_length1 = 0;
		gint _size_collection_size_ = 0;
		gint size_it = 0;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		size_collection = _tmp37_;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		size_collection_length1 = _tmp37__length1;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (size_it = 0; size_it < size_collection_length1; size_it = size_it + 1) {
#line 2052 "TextBar.c"
			gint size = 0;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			size = size_collection[size_it];
#line 2056 "TextBar.c"
			{
				SpiceEntryCombo* _tmp38_;
				gchar* _tmp39_;
				gchar* _tmp40_;
				GtkLabel* _tmp41_;
				GtkLabel* _tmp42_;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp38_ = self->priv->font_size;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp39_ = g_strdup_printf ("%i", size);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp40_ = _tmp39_;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp41_ = spice_entry_combo_add_entry (_tmp38_, _tmp40_, NULL);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp42_ = _tmp41_;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_object_unref0 (_tmp42_);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_g_free0 (_tmp40_);
#line 2077 "TextBar.c"
			}
		}
	}
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp43_ = (GtkImage*) gtk_image_new_from_icon_name ("format-justify-fill-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp43_);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->align_button_image);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->align_button_image = _tmp43_;
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp44_ = (GtkButton*) gtk_button_new ();
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp44_);
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	align_button = _tmp44_;
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp45_ = align_button;
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp46_ = gtk_widget_get_style_context ((GtkWidget*) _tmp45_);
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_style_context_add_class (_tmp46_, GTK_STYLE_CLASS_RAISED);
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp47_ = align_button;
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp47_, _ ("Align"));
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp48_ = align_button;
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp49_ = self->priv->align_button_image;
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) _tmp48_, (GtkWidget*) _tmp49_);
#line 94 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp50_ = (GtkGrid*) gtk_grid_new ();
#line 94 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp50_);
#line 94 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	align_grid = _tmp50_;
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp51_ = align_grid;
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp51_, GTK_ORIENTATION_VERTICAL);
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp52_ = align_grid;
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_grid_set_row_spacing (_tmp52_, 6);
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp53_ = align_grid;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_set ((GtkWidget*) _tmp53_, "margin", 6, NULL);
#line 99 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp54_ = align_button;
#line 99 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp55_ = (GtkPopover*) gtk_popover_new ((GtkWidget*) _tmp54_);
#line 99 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp55_);
#line 99 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_data25_->align_popover = _tmp55_;
#line 100 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp56_ = _data25_->align_popover;
#line 100 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_popover_set_position (_tmp56_, GTK_POS_BOTTOM);
#line 101 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp57_ = _data25_->align_popover;
#line 101 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp58_ = align_grid;
#line 101 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) _tmp57_, (GtkWidget*) _tmp58_);
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp59_ = align_button;
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_data (_tmp59_, "clicked", (GCallback) __spice_widgets_text_toolbar___lambda108__gtk_button_clicked, block25_data_ref (_data25_), (GClosureNotify) block25_data_unref, 0);
#line 107 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp60_ = granite_widgets_mode_button_new ();
#line 107 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp60_);
#line 107 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->justification);
#line 107 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->justification = _tmp60_;
#line 108 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp61_ = self->priv->justification;
#line 108 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp61_, "mode-added", (GCallback) __spice_widgets_text_toolbar___lambda109__granite_widgets_mode_button_mode_added, self, 0);
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp62_ = self->priv->justification;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append_icon (_tmp62_, "format-justify-left-symbolic", GTK_ICON_SIZE_MENU);
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp63_ = self->priv->justification;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append_icon (_tmp63_, "format-justify-center-symbolic", GTK_ICON_SIZE_MENU);
#line 115 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp64_ = self->priv->justification;
#line 115 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append_icon (_tmp64_, "format-justify-right-symbolic", GTK_ICON_SIZE_MENU);
#line 116 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp65_ = self->priv->justification;
#line 116 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append_icon (_tmp65_, "format-justify-fill-symbolic", GTK_ICON_SIZE_MENU);
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp66_ = self->priv->justification;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp67_ = gtk_container_get_children ((GtkContainer*) _tmp66_);
#line 2183 "TextBar.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		child_collection = _tmp67_;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 2191 "TextBar.c"
			GtkWidget* child = NULL;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			child = (GtkWidget*) child_it->data;
#line 2195 "TextBar.c"
			{
				GtkWidget* _tmp68_;
				GtkStyleContext* _tmp69_;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp68_ = child;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp69_ = gtk_widget_get_style_context (_tmp68_);
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				gtk_style_context_add_class (_tmp69_, GTK_STYLE_CLASS_RAISED);
#line 2205 "TextBar.c"
			}
		}
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		(child_collection == NULL) ? NULL : (child_collection = (g_list_free (child_collection), NULL));
#line 2210 "TextBar.c"
	}
#line 122 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp70_ = granite_widgets_mode_button_new ();
#line 122 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp70_);
#line 122 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->align);
#line 122 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->align = _tmp70_;
#line 123 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp71_ = self->priv->align;
#line 123 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_signal_connect_object (_tmp71_, "mode-added", (GCallback) __spice_widgets_text_toolbar___lambda110__granite_widgets_mode_button_mode_added, self, 0);
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp72_ = self->priv->align;
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp73_ = (GtkImage*) gtk_image_new_from_resource ("/com/github/philip-scott/spice-up/align-top-symbolic");
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp73_);
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp74_ = _tmp73_;
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append (_tmp72_, (GtkWidget*) _tmp74_);
#line 128 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (_tmp74_);
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp75_ = self->priv->align;
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp76_ = (GtkImage*) gtk_image_new_from_resource ("/com/github/philip-scott/spice-up/align-middle-symbolic");
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp76_);
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp77_ = _tmp76_;
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append (_tmp75_, (GtkWidget*) _tmp77_);
#line 129 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (_tmp77_);
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp78_ = self->priv->align;
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp79_ = (GtkImage*) gtk_image_new_from_resource ("/com/github/philip-scott/spice-up/align-bottom-symbolic");
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_object_ref_sink (_tmp79_);
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp80_ = _tmp79_;
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	granite_widgets_mode_button_append (_tmp78_, (GtkWidget*) _tmp80_);
#line 130 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (_tmp80_);
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp81_ = self->priv->align;
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp82_ = gtk_container_get_children ((GtkContainer*) _tmp81_);
#line 2264 "TextBar.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		child_collection = _tmp82_;
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 2272 "TextBar.c"
			GtkWidget* child = NULL;
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
			child = (GtkWidget*) child_it->data;
#line 2276 "TextBar.c"
			{
				GtkWidget* _tmp83_;
				GtkStyleContext* _tmp84_;
#line 133 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp83_ = child;
#line 133 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				_tmp84_ = gtk_widget_get_style_context (_tmp83_);
#line 133 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
				gtk_style_context_add_class (_tmp84_, GTK_STYLE_CLASS_RAISED);
#line 2286 "TextBar.c"
			}
		}
#line 132 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
		(child_collection == NULL) ? NULL : (child_collection = (g_list_free (child_collection), NULL));
#line 2291 "TextBar.c"
	}
#line 136 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp85_ = self->priv->text_color_button;
#line 136 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp85_);
#line 137 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp86_ = self->priv->font_button;
#line 137 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp86_);
#line 138 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp87_ = self->priv->font_size;
#line 138 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp87_);
#line 139 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp88_ = self->priv->font_type;
#line 139 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp88_);
#line 140 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp89_ = align_button;
#line 140 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp89_);
#line 142 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp90_ = align_grid;
#line 142 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp91_ = self->priv->justification;
#line 142 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) _tmp90_, (GtkWidget*) _tmp91_);
#line 143 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp92_ = align_grid;
#line 143 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp93_ = self->priv->align;
#line 143 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	gtk_container_add ((GtkContainer*) _tmp92_, (GtkWidget*) _tmp93_);
#line 145 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_text_toolbar_connect_signals (self);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (align_grid);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (align_button);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	font_sizes = (g_free (font_sizes), NULL);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	block25_data_unref (_data25_);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_data25_ = NULL;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	return obj;
#line 2339 "TextBar.c"
}

static void
spice_widgets_text_toolbar_class_init (SpiceWidgetsTextToolbarClass * klass,
                                       gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	spice_widgets_text_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceWidgetsTextToolbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->item_selected = (void (*) (SpiceWidgetsToolbar*, SpiceCanvasItem*, gboolean)) spice_widgets_text_toolbar_real_item_selected;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->update_properties = (void (*) (SpiceWidgetsToolbar*)) spice_widgets_text_toolbar_real_update_properties;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_widgets_text_toolbar_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_widgets_text_toolbar_finalize;
#line 2358 "TextBar.c"
}

static void
spice_widgets_text_toolbar_instance_init (SpiceWidgetsTextToolbar * self,
                                          gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv = spice_widgets_text_toolbar_get_instance_private (self);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp0_ = g_strdup (_ ("Left"));
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp1_ = g_strdup (_ ("Center"));
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp2_ = g_strdup (_ ("Right"));
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp3_ = g_strdup (_ ("Justify"));
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_[0] = _tmp0_;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_[1] = _tmp1_;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_[2] = _tmp2_;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp4_[3] = _tmp3_;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->JUSTIFICATION_TRANSLATIONS = _tmp4_;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->JUSTIFICATION_TRANSLATIONS_length1 = 4;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->_JUSTIFICATION_TRANSLATIONS_size_ = self->priv->JUSTIFICATION_TRANSLATIONS_length1;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp5_ = g_strdup (_ ("Top"));
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp6_ = g_strdup (_ ("Middle"));
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp7_ = g_strdup (_ ("Bottom"));
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_ = g_new0 (gchar*, 3 + 1);
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_[0] = _tmp5_;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_[1] = _tmp6_;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_tmp8_[2] = _tmp7_;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->ALIGN_TRANSLATIONS = _tmp8_;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->ALIGN_TRANSLATIONS_length1 = 3;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->_ALIGN_TRANSLATIONS_size_ = self->priv->ALIGN_TRANSLATIONS_length1;
#line 2420 "TextBar.c"
}

static void
spice_widgets_text_toolbar_finalize (GObject * obj)
{
	SpiceWidgetsTextToolbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbar);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->families = (_vala_array_free (self->priv->families, self->priv->families_length1, (GDestroyNotify) g_object_unref), NULL);
#line 24 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->family_cache);
#line 25 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->face_cache);
#line 26 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->justification);
#line 27 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->align);
#line 28 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_button);
#line 29 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->text_color_button);
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_size);
#line 31 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->font_type);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	_g_object_unref0 (self->priv->align_button_image);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->JUSTIFICATION_TRANSLATIONS = (_vala_array_free (self->priv->JUSTIFICATION_TRANSLATIONS, self->priv->JUSTIFICATION_TRANSLATIONS_length1, (GDestroyNotify) g_free), NULL);
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	self->priv->ALIGN_TRANSLATIONS = (_vala_array_free (self->priv->ALIGN_TRANSLATIONS, self->priv->ALIGN_TRANSLATIONS_length1, (GDestroyNotify) g_free), NULL);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/TextBar.vala"
	G_OBJECT_CLASS (spice_widgets_text_toolbar_parent_class)->finalize (obj);
#line 2455 "TextBar.c"
}

static GType
spice_widgets_text_toolbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceWidgetsTextToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_widgets_text_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceWidgetsTextToolbar), 0, (GInstanceInitFunc) spice_widgets_text_toolbar_instance_init, NULL };
	GType spice_widgets_text_toolbar_type_id;
	spice_widgets_text_toolbar_type_id = g_type_register_static (SPICE_WIDGETS_TYPE_TOOLBAR, "SpiceWidgetsTextToolbar", &g_define_type_info, 0);
	SpiceWidgetsTextToolbar_private_offset = g_type_add_instance_private (spice_widgets_text_toolbar_type_id, sizeof (SpiceWidgetsTextToolbarPrivate));
	return spice_widgets_text_toolbar_type_id;
}

GType
spice_widgets_text_toolbar_get_type (void)
{
	static volatile gsize spice_widgets_text_toolbar_type_id__once = 0;
	if (g_once_init_enter (&spice_widgets_text_toolbar_type_id__once)) {
		GType spice_widgets_text_toolbar_type_id;
		spice_widgets_text_toolbar_type_id = spice_widgets_text_toolbar_get_type_once ();
		g_once_init_leave (&spice_widgets_text_toolbar_type_id__once, spice_widgets_text_toolbar_type_id);
	}
	return spice_widgets_text_toolbar_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

